##  Summary
This tutorial provided detailed guidance on how to create a custom matrix report showing the lifecycle phases of application fact sheets. You learned how to:
  * Use the [fixedFactSheetType![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fleanix.github.io%2Fleanix-reporting%2Fclasses%2Flxr.LxCustomReportLib.html%23openFormModal "https://leanix.github.io/leanix-reporting/classes/lxr.LxCustomReportLib.html#openFormModal") option to restrict data retrieval to a specific fact sheet type
  * Use the setup object that contains information about your workspace and meta model configuration
  * Incorporate additional HTML elements into the structure of your custom reports project to ensure that your custom report is rendered properly
